← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~suutari-olli/openlp/ui-messages-part-1 into lp:openlp

 

Azaziah has proposed merging lp:~suutari-olli/openlp/ui-messages-part-1 into lp:openlp.

Requested reviews:
  OpenLP Core (openlp-core)

For more details, see:
https://code.launchpad.net/~suutari-olli/openlp/ui-messages-part-1/+merge/291447

This branch includes the following UI string changes:
- Media Manager, Projector Manager, Service Manager, Theme Manager, 
   Preview Panel and Live Panel have been renamed to: ”Library, 
   Projectors, Service, Themes, Preview and Live."
- Tooltips/texts for these have been changed.
- Removed version from window title 
- Removed version from web remote page window names.
- Re-did the trace back message.
- Some other changes

In "Configurate OpenLP":
- Changed typing for all labels to lowercase
- Removed "Manager" from some strings since it's no longer used.
- Added dots to various tooltips / descriptions.
- In advanced tab: Number of recent files to display: 
  has been changed to Number of recent Service files to display:

Do note that Jenkins is currently broken due to the crosswalk Bible test.
lp:~suutari-olli/openlp/ui-messages-part-1 (revision 2636)
[←[1;32mSUCCESS←[1;m] https://ci.openlp.io/job/Branch-01-Pull/1413/
[←[1;32mSUCCESS←[1;m] https://ci.openlp.io/job/Branch-02-Functional-Tests/1331/
[←[1;31mFAILURE←[1;m] https://ci.openlp.io/job/Branch-03-Interface-Tests/1270/
Stopping after failure

-- 
Your team OpenLP Core is requested to review the proposed merge of lp:~suutari-olli/openlp/ui-messages-part-1 into lp:openlp.
=== modified file 'openlp/core/ui/advancedtab.py'
--- openlp/core/ui/advancedtab.py	2016-04-05 17:30:20 +0000
+++ openlp/core/ui/advancedtab.py	2016-04-10 00:27:48 +0000
@@ -273,15 +273,15 @@
         self.tab_title_visible = UiStrings().Advanced
         self.ui_group_box.setTitle(translate('OpenLP.AdvancedTab', 'UI Settings'))
         self.data_directory_group_box.setTitle(translate('OpenLP.AdvancedTab', 'Data Location'))
-        self.recent_label.setText(translate('OpenLP.AdvancedTab', 'Number of recent files to display:'))
+        self.recent_label.setText(translate('OpenLP.AdvancedTab', 'Number of recent service files to display:'))
         self.media_plugin_check_box.setText(translate('OpenLP.AdvancedTab',
-                                                      'Remember active media manager tab on startup'))
+                                                      'Open the last used library category on startup'))
         self.double_click_live_check_box.setText(translate('OpenLP.AdvancedTab',
                                                            'Double-click to send items straight to live'))
         self.single_click_preview_check_box.setText(translate('OpenLP.AdvancedTab',
-                                                              'Preview items when clicked in Media Manager'))
+                                                              'Preview items when clicked in library'))
         self.single_click_service_preview_check_box.setText(translate('OpenLP.AdvancedTab',
-                                                                      'Preview items when clicked in Service Manager'))
+                                                                      'Preview items when clicked in service'))
         self.expand_service_item_check_box.setText(translate('OpenLP.AdvancedTab',
                                                              'Expand new service items on creation'))
         self.slide_max_height_label.setText(translate('OpenLP.AdvancedTab',

=== modified file 'openlp/core/ui/exceptiondialog.py'
--- openlp/core/ui/exceptiondialog.py	2015-12-31 22:46:06 +0000
+++ openlp/core/ui/exceptiondialog.py	2016-04-10 00:27:48 +0000
@@ -43,6 +43,8 @@
         self.exception_layout.setObjectName('exception_layout')
         self.message_layout = QtWidgets.QHBoxLayout()
         self.message_layout.setObjectName('messageLayout')
+        # Set margin to make the box a bit wider so the traceback is easier to read. (left, top, right, bottom)
+        self.message_layout.setContentsMargins(0, 0, 50, 0)
         self.message_layout.addSpacing(12)
         self.bug_label = QtWidgets.QLabel(exception_dialog)
         self.bug_label.setPixmap(QtGui.QPixmap(':/graphics/exception.png'))
@@ -90,15 +92,18 @@
         """
         exception_dialog.setWindowTitle(translate('OpenLP.ExceptionDialog', 'Error Occurred'))
         self.description_explanation.setText(
-            translate('OpenLP.ExceptionDialog', 'Please enter a description of what you were doing to cause this error.'
-                                                ' If possible, write in English.'
-                                                '\n(Minimum 20 characters)'))
+            translate('OpenLP.ExceptionDialog', '<strong>Please describe what you were trying to do.</strong> '
+                                                '&nbsp;If possible, write in English.'))
         self.message_label.setText(
-            translate('OpenLP.ExceptionDialog', 'Oops! OpenLP hit a problem, and couldn\'t recover. The text in the '
-                                                'box below contains information that might be helpful to the OpenLP '
-                                                'developers, so please e-mail it to bugs@xxxxxxxxxx, along with a '
-                                                'detailed description of what you were doing when the problem '
-                                                'occurred. Also attach any files that triggered the problem.'))
+            translate('OpenLP.ExceptionDialog', '<strong>Oops, OpenLP hit a problem '
+                      'and couldn\'t recover!</strong> <br><br>'
+                      '<strong>You can help </strong> OpenLP developers to fix this by<br>'
+                      'sending them a <strong>bug report</strong> '
+                      'to  <a href="mailto:bugs@xxxxxxxxxx";> bugs@xxxxxxxxxx </a> <br> <br>'
+                      '<strong>No email app? </strong> You can <strong>save</strong> this '
+                      'information to a <strong>file</strong> and<br>'
+                      'send it from your <strong>mail on browser</strong> via an <strong>attachement.</strong><br><br>'
+                      '<strong>Thank you<strong> for being part of making OpenLP better!'))
         self.send_report_button.setText(translate('OpenLP.ExceptionDialog', 'Send E-Mail'))
         self.save_report_button.setText(translate('OpenLP.ExceptionDialog', 'Save to File'))
         self.attach_tile_button.setText(translate('OpenLP.ExceptionDialog', 'Attach File'))

=== modified file 'openlp/core/ui/exceptionform.py'
--- openlp/core/ui/exceptionform.py	2016-04-04 19:53:54 +0000
+++ openlp/core/ui/exceptionform.py	2016-04-10 00:27:48 +0000
@@ -199,7 +199,7 @@
         else:
             self.__button_state(False)
         self.description_word_count.setText(
-            translate('OpenLP.ExceptionDialog', 'Description characters to enter : %s') % count)
+            translate('OpenLP.ExceptionDialog', '%s Characters from the minimum description remaining.') % count)
 
     def on_attach_file_button_clicked(self):
         """

=== modified file 'openlp/core/ui/mainwindow.py'
--- openlp/core/ui/mainwindow.py	2016-04-04 19:53:54 +0000
+++ openlp/core/ui/mainwindow.py	2016-04-10 00:27:48 +0000
@@ -385,21 +385,21 @@
         """
         Set up the translation system
         """
-        main_window.setWindowTitle(UiStrings().OLPV2x)
+        main_window.setWindowTitle(UiStrings().OLP)
         self.file_menu.setTitle(translate('OpenLP.MainWindow', '&File'))
         self.file_import_menu.setTitle(translate('OpenLP.MainWindow', '&Import'))
         self.file_export_menu.setTitle(translate('OpenLP.MainWindow', '&Export'))
         self.recent_files_menu.setTitle(translate('OpenLP.MainWindow', '&Recent Services'))
         self.view_menu.setTitle(translate('OpenLP.MainWindow', '&View'))
-        self.view_mode_menu.setTitle(translate('OpenLP.MainWindow', 'M&ode'))
+        self.view_mode_menu.setTitle(translate('OpenLP.MainWindow', '&Layout Presets'))
         self.tools_menu.setTitle(translate('OpenLP.MainWindow', '&Tools'))
         self.settings_menu.setTitle(translate('OpenLP.MainWindow', '&Settings'))
         self.settings_language_menu.setTitle(translate('OpenLP.MainWindow', '&Language'))
         self.help_menu.setTitle(translate('OpenLP.MainWindow', '&Help'))
         self.media_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Library'))
-        self.service_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Service Manager'))
-        self.theme_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Theme Manager'))
-        self.projector_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Projector Manager'))
+        self.service_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Service'))
+        self.theme_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Themes'))
+        self.projector_manager_dock.setWindowTitle(translate('OpenLP.MainWindow', 'Projectors'))
         self.file_new_item.setText(translate('OpenLP.MainWindow', '&New Service'))
         self.file_new_item.setToolTip(UiStrings().NewService)
         self.file_new_item.setStatusTip(UiStrings().CreateService)
@@ -416,7 +416,7 @@
         self.print_service_order_item.setText(UiStrings().PrintService)
         self.print_service_order_item.setStatusTip(translate('OpenLP.MainWindow', 'Print the current service.'))
         self.file_exit_item.setText(translate('OpenLP.MainWindow', 'E&xit'))
-        self.file_exit_item.setStatusTip(translate('OpenLP.MainWindow', 'Quit OpenLP'))
+        self.file_exit_item.setStatusTip(translate('OpenLP.MainWindow', 'Exit OpenLP - Shut down the program.'))
         self.import_theme_item.setText(translate('OpenLP.MainWindow', '&Theme'))
         self.import_language_item.setText(translate('OpenLP.MainWindow', '&Language'))
         self.export_theme_item.setText(translate('OpenLP.MainWindow', '&Theme'))
@@ -425,41 +425,42 @@
         self.formatting_tag_item.setText(translate('OpenLP.MainWindow', 'Configure &Formatting Tags...'))
         self.settings_configure_item.setText(translate('OpenLP.MainWindow', '&Configure OpenLP...'))
         self.settings_export_item.setStatusTip(
-            translate('OpenLP.MainWindow', 'Export OpenLP settings to a specified *.config file'))
+            translate('OpenLP.MainWindow', 'Export settings to a .config file.'))
         self.settings_export_item.setText(translate('OpenLP.MainWindow', 'Settings'))
         self.settings_import_item.setStatusTip(
-            translate('OpenLP.MainWindow', 'Import OpenLP settings from a specified *.config file previously '
-                                           'exported on this or another machine'))
+            translate('OpenLP.MainWindow', 'Import settings from a .config file previously exported from '
+                                           'this or an another machine.'))
         self.settings_import_item.setText(translate('OpenLP.MainWindow', 'Settings'))
-        self.view_projector_manager_item.setText(translate('OPenLP.MainWindow', '&Projector Manager'))
-        self.view_projector_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Toggle Projector Manager'))
+        self.view_projector_manager_item.setText(translate('OPenLP.MainWindow', '&Projectors'))
+        self.view_projector_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Hide or show Projectors.'))
         self.view_projector_manager_item.setStatusTip(translate('OpenLP.MainWindow',
-                                                                'Toggle the visibility of the Projector Manager'))
-        self.view_media_manager_item.setText(translate('OpenLP.MainWindow', '&Media Manager'))
-        self.view_media_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Toggle Media Manager'))
+                                                                'Toggle the visibility of the Projectors.'))
+        self.view_media_manager_item.setText(translate('OpenLP.MainWindow', 'L&ibrary'))
+        self.view_media_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Hide or show the Library.'))
         self.view_media_manager_item.setStatusTip(translate('OpenLP.MainWindow',
-                                                  'Toggle the visibility of the media manager.'))
-        self.view_theme_manager_item.setText(translate('OpenLP.MainWindow', '&Theme Manager'))
-        self.view_theme_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Toggle Theme Manager'))
+                                                  'Toggle the visibility of the Library.'))
+        self.view_theme_manager_item.setText(translate('OpenLP.MainWindow', '&Themes'))
+        self.view_theme_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Hide or show Themes'))
         self.view_theme_manager_item.setStatusTip(translate('OpenLP.MainWindow',
-                                                  'Toggle the visibility of the theme manager.'))
-        self.view_service_manager_item.setText(translate('OpenLP.MainWindow', '&Service Manager'))
-        self.view_service_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Toggle Service Manager'))
+                                                  'Toggle the visibility of the Themes.'))
+        self.view_service_manager_item.setText(translate('OpenLP.MainWindow', '&Service'))
+        self.view_service_manager_item.setToolTip(translate('OpenLP.MainWindow', 'Hide or show Service.'))
         self.view_service_manager_item.setStatusTip(translate('OpenLP.MainWindow',
-                                                    'Toggle the visibility of the service manager.'))
-        self.view_preview_panel.setText(translate('OpenLP.MainWindow', '&Preview Panel'))
-        self.view_preview_panel.setToolTip(translate('OpenLP.MainWindow', 'Toggle Preview Panel'))
+                                                    'Toggle the visibility of the Service.'))
+        self.view_preview_panel.setText(translate('OpenLP.MainWindow', '&Preview'))
+        self.view_preview_panel.setToolTip(translate('OpenLP.MainWindow', 'Hide or show Preview.'))
         self.view_preview_panel.setStatusTip(
-            translate('OpenLP.MainWindow', 'Toggle the visibility of the preview panel.'))
-        self.view_live_panel.setText(translate('OpenLP.MainWindow', '&Live Panel'))
-        self.view_live_panel.setToolTip(translate('OpenLP.MainWindow', 'Toggle Live Panel'))
-        self.lock_panel.setText(translate('OpenLP.MainWindow', 'L&ock Panels'))
-        self.lock_panel.setStatusTip(translate('OpenLP.MainWindow', 'Prevent the panels being moved.'))
-        self.view_live_panel.setStatusTip(translate('OpenLP.MainWindow', 'Toggle the visibility of the live panel.'))
+            translate('OpenLP.MainWindow', 'Toggle the visibility of the Preview.'))
+        self.view_live_panel.setText(translate('OpenLP.MainWindow', 'Li&ve'))
+        self.view_live_panel.setToolTip(translate('OpenLP.MainWindow', 'Hide or show Live'))
+        self.lock_panel.setText(translate('OpenLP.MainWindow', 'L&ock visibility of the panels'))
+        self.lock_panel.setStatusTip(translate('OpenLP.MainWindow', 'Lock visibility of the panels.'))
+        self.view_live_panel.setStatusTip(translate('OpenLP.MainWindow', 'Toggle the visibility of the Live.'))
         self.settings_plugin_list_item.setText(translate('OpenLP.MainWindow', '&Manage Plugins'))
-        self.settings_plugin_list_item.setStatusTip(translate('OpenLP.MainWindow', 'List the Plugins'))
+        self.settings_plugin_list_item.setStatusTip(translate('OpenLP.MainWindow', 'You can activate or disable plugins'
+                                                                                   'from here.'))
         self.about_item.setText(translate('OpenLP.MainWindow', '&About'))
-        self.about_item.setStatusTip(translate('OpenLP.MainWindow', 'More information about OpenLP'))
+        self.about_item.setStatusTip(translate('OpenLP.MainWindow', 'More information about OpenLP.'))
         if is_win() or is_macosx():
             self.offline_help_item.setText(translate('OpenLP.MainWindow', '&User Guide'))
         self.on_line_help_item.setText(translate('OpenLP.MainWindow', '&Online Help'))
@@ -485,11 +486,13 @@
         self.update_theme_images.setStatusTip(translate('OpenLP.MainWindow',
                                                         'Update the preview images for all themes.'))
         self.mode_default_item.setText(translate('OpenLP.MainWindow', '&Default'))
-        self.mode_default_item.setStatusTip(translate('OpenLP.MainWindow', 'Set the view mode back to the default.'))
+        self.mode_default_item.setStatusTip(translate('OpenLP.MainWindow', 'Reset the interface layout back to the '
+                                                                           'default settings.'))
         self.mode_setup_item.setText(translate('OpenLP.MainWindow', '&Setup'))
-        self.mode_setup_item.setStatusTip(translate('OpenLP.MainWindow', 'Set the view mode to Setup.'))
+        self.mode_setup_item.setStatusTip(translate('OpenLP.MainWindow', 'Use layout that focuses on setting'
+                                                                         ' up the Service.'))
         self.mode_live_item.setText(translate('OpenLP.MainWindow', '&Live'))
-        self.mode_live_item.setStatusTip(translate('OpenLP.MainWindow', 'Set the view mode to Live.'))
+        self.mode_live_item.setStatusTip(translate('OpenLP.MainWindow', 'Use layout that focuses on Live.'))
 
 
 class MainWindow(QtWidgets.QMainWindow, Ui_MainWindow, RegistryProperties):
@@ -851,9 +854,9 @@
             return
         import_file_name, filter_used = QtWidgets.QFileDialog.getOpenFileName(
             self,
-            translate('OpenLP.MainWindow', 'Open File'),
+            translate('OpenLP.MainWindow', 'Import settings'),
             '',
-            translate('OpenLP.MainWindow', 'OpenLP Export Settings Files (*.conf)'))
+            translate('OpenLP.MainWindow', 'OpenLP Settings (.conf)'))
         if not import_file_name:
             return
         setting_sections = []
@@ -943,7 +946,7 @@
             self,
             translate('OpenLP.MainWindow', 'Export Settings File'),
             '',
-            translate('OpenLP.MainWindow', 'OpenLP Export Settings File (*.conf)'))
+            translate('OpenLP.MainWindow', 'Exported OpenLP Settings (.conf)'))
         if not export_file_name:
             return
             # Make sure it's a .conf file.
@@ -1153,9 +1156,9 @@
         :param file_name: The file name of the service file.
         """
         if modified:
-            title = '%s - %s*' % (UiStrings().OLPV2x, file_name)
+            title = '%s - %s*' % (UiStrings().OLP, file_name)
         else:
-            title = '%s - %s' % (UiStrings().OLPV2x, file_name)
+            title = '%s - %s' % (UiStrings().OLP, file_name)
         self.setWindowTitle(title)
 
     def show_status_message(self, message):

=== modified file 'openlp/core/ui/media/playertab.py'
--- openlp/core/ui/media/playertab.py	2015-12-31 22:46:06 +0000
+++ openlp/core/ui/media/playertab.py	2016-04-10 00:27:48 +0000
@@ -125,7 +125,7 @@
         self.media_player_group_box.setTitle(translate('OpenLP.PlayerTab', 'Available Media Players'))
         self.player_order_group_box.setTitle(translate('OpenLP.PlayerTab', 'Player Search Order'))
         self.background_color_group_box.setTitle(UiStrings().BackgroundColor)
-        self.background_color_label.setText(UiStrings().DefaultColor)
+        self.background_color_label.setText(UiStrings().BackgroundColor)
         self.information_label.setText(translate('OpenLP.PlayerTab',
                                        'Visible background for videos with aspect ratio different to screen.'))
         self.retranslate_players()

=== modified file 'openlp/plugins/bibles/lib/biblestab.py'
--- openlp/plugins/bibles/lib/biblestab.py	2015-12-31 22:46:06 +0000
+++ openlp/plugins/bibles/lib/biblestab.py	2016-04-10 00:27:48 +0000
@@ -174,10 +174,10 @@
                                        'Note:\nChanges do not affect verses already in the service.'))
         self.bible_second_check_box.setText(translate('BiblesPlugin.BiblesTab', 'Display second Bible verses'))
         self.scripture_reference_group_box.setTitle(translate('BiblesPlugin.BiblesTab', 'Custom Scripture References'))
-        self.verse_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'Verse Separator:'))
-        self.range_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'Range Separator:'))
-        self.list_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'List Separator:'))
-        self.end_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'End Mark:'))
+        self.verse_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'Verse separator:'))
+        self.range_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'Range separator:'))
+        self.list_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'List separator:'))
+        self.end_separator_check_box.setText(translate('BiblesPlugin.BiblesTab', 'End mark:'))
         tip_text = translate('BiblesPlugin.BiblesTab',
                              'Multiple alternative verse separators may be defined.\nThey have to be separated by a '
                              'vertical bar "|".\nPlease clear this edit line to use the default value.')

=== modified file 'openlp/plugins/media/lib/mediaitem.py'
--- openlp/plugins/media/lib/mediaitem.py	2016-04-03 19:44:09 +0000
+++ openlp/plugins/media/lib/mediaitem.py	2016-04-10 00:27:48 +0000
@@ -138,7 +138,7 @@
             disable_optical_button_text = True
             optical_button_text = translate('MediaPlugin.MediaItem', 'Load CD/DVD')
             optical_button_tooltip = translate('MediaPlugin.MediaItem',
-                                               'Load CD/DVD - only supported when VLC is installed and enabled')
+                                               'CD/DVD Playback is only supported if VLC is installed and enabled.')
         self.load_optical = self.toolbar.add_toolbar_action('load_optical', icon=self.optical_icon,
                                                             text=optical_button_text,
                                                             tooltip=optical_button_tooltip,

=== modified file 'openlp/plugins/media/lib/mediatab.py'
--- openlp/plugins/media/lib/mediatab.py	2015-12-31 22:46:06 +0000
+++ openlp/plugins/media/lib/mediatab.py	2016-04-10 00:27:48 +0000
@@ -54,7 +54,7 @@
     def retranslateUi(self):
         self.advanced_group_box.setTitle(UiStrings().Advanced)
         self.override_player_check_box.setText(translate('MediaPlugin.MediaTab', 'Allow media player to be overridden'))
-        self.auto_start_check_box.setText(translate('MediaPlugin.MediaTab', 'Start Live items automatically'))
+        self.auto_start_check_box.setText(translate('MediaPlugin.MediaTab', 'Start live items automatically'))
 
     def load(self):
         self.override_player_check_box.setChecked(Settings().value(self.settings_section + '/override player'))

=== modified file 'openlp/plugins/presentations/lib/presentationtab.py'
--- openlp/plugins/presentations/lib/presentationtab.py	2015-12-31 22:46:06 +0000
+++ openlp/plugins/presentations/lib/presentationtab.py	2016-04-10 00:27:48 +0000
@@ -125,7 +125,7 @@
             translate('PresentationPlugin.PresentationTab', 'Allow presentation application to be overridden'))
         self.ppt_slide_click_check_box.setText(
             translate('PresentationPlugin.PresentationTab',
-                      'Clicking on a selected slide in the slidecontroller advances to next effect.'))
+                      'Clicking on a selected slide in Live advances to the next effect.'))
         self.ppt_window_check_box.setText(
             translate('PresentationPlugin.PresentationTab',
                       'Let PowerPoint control the size and position of the presentation window '
@@ -151,7 +151,7 @@
             if controller.name == 'Powerpoint' and controller.is_available():
                 powerpoint_available = True
         self.override_app_check_box.setChecked(Settings().value(self.settings_section + '/override app'))
-        # Load Powerpoint settings
+        # Load PowerPoint settings
         self.ppt_slide_click_check_box.setChecked(Settings().value(self.settings_section +
                                                                    '/powerpoint slide click advance'))
         self.ppt_slide_click_check_box.setEnabled(powerpoint_available)

=== modified file 'openlp/plugins/remotes/lib/httprouter.py'
--- openlp/plugins/remotes/lib/httprouter.py	2016-03-19 19:42:10 +0000
+++ openlp/plugins/remotes/lib/httprouter.py	2016-04-10 00:27:48 +0000
@@ -312,12 +312,11 @@
         Translate various strings in the mobile app.
         """
         remote = translate('RemotePlugin.Mobile', 'Remote')
-        stage = translate('RemotePlugin.Mobile', 'Stage View')
-        live = translate('RemotePlugin.Mobile', 'Live View')
+        stage = translate('RemotePlugin.Mobile', 'Stage')
         self.template_vars = {
-            'app_title': "%s %s" % (UiStrings().OLPV2x, remote),
-            'stage_title': "%s %s" % (UiStrings().OLPV2x, stage),
-            'live_title': "%s %s" % (UiStrings().OLPV2x, live),
+            'app_title': "OpenLP | %s" % remote,
+            'stage_title': "OpenLP | %s" % stage,
+            'live_title': "OpenLP | %s" % UiStrings().Live,
             'service_manager': translate('RemotePlugin.Mobile', 'Service Manager'),
             'slide_controller': translate('RemotePlugin.Mobile', 'Slide Controller'),
             'alerts': translate('RemotePlugin.Mobile', 'Alerts'),

=== modified file 'tests/functional/openlp_core_ui/test_mainwindow.py'
--- tests/functional/openlp_core_ui/test_mainwindow.py	2016-01-15 20:37:53 +0000
+++ tests/functional/openlp_core_ui/test_mainwindow.py	2016-04-10 00:27:48 +0000
@@ -108,9 +108,9 @@
 
         # WHEN no changes are made to the service
 
-        # THEN the main window's title shoud be the same as the OLPV2x string in the UiStrings class
-        self.assertEqual(self.main_window.windowTitle(), UiStrings().OLPV2x,
-                         'The main window\'s title should be the same as the OLPV2x string in UiStrings class')
+        # THEN the main window's title shoud be the same as the OLP string in the UiStrings class
+        self.assertEqual(self.main_window.windowTitle(), UiStrings().OLP,
+                         'The main window\'s title should be the same as the OLP string in UiStrings class')
 
     def set_service_modifed_test(self):
         """
@@ -122,8 +122,8 @@
         self.main_window.set_service_modified(True, 'test.osz')
 
         # THEN the main window's title should be set to the
-        self.assertEqual(self.main_window.windowTitle(), '%s - %s*' % (UiStrings().OLPV2x, 'test.osz'),
-                         'The main window\'s title should be set to "<the contents of UiStrings().OLPV2x> - test.osz*"')
+        self.assertEqual(self.main_window.windowTitle(), '%s - %s*' % (UiStrings().OLP, 'test.osz'),
+                         'The main window\'s title should be set to "<the contents of UiStrings().OLP> - test.osz*"')
 
     def set_service_unmodified_test(self):
         """
@@ -135,8 +135,8 @@
         self.main_window.set_service_modified(False, 'test.osz')
 
         # THEN the main window's title should be set to the
-        self.assertEqual(self.main_window.windowTitle(), '%s - %s' % (UiStrings().OLPV2x, 'test.osz'),
-                         'The main window\'s title should be set to "<the contents of UiStrings().OLPV2x> - test.osz"')
+        self.assertEqual(self.main_window.windowTitle(), '%s - %s' % (UiStrings().OLP, 'test.osz'),
+                         'The main window\'s title should be set to "<the contents of UiStrings().OLP> - test.osz"')
 
     def mainwindow_configuration_test(self):
         """


Follow ups